pub struct SerializableRegex { /* private fields */ }Expand description
A wrapper type for fancy_regex::Regex that implements Serialize, Deserialize, PartialEq, Eq
This wrapper allows storing and serializing regular expressions by storing the pattern string alongside the compiled regex object.
Examples
use gooty_proxy::utils::SerializableRegex;
let regex = SerializableRegex::new(r"\d{3}").unwrap();
assert!(regex.is_match("123").unwrap());
// Serialize and deserialize with serde
let serialized = serde_json::to_string(®ex).unwrap();
let deserialized: SerializableRegex = serde_json::from_str(&serialized).unwrap();
assert_eq!(regex, deserialized);Implementations